# ACCESS-NRI Intake Utilities

## Tools for interacting with intake catalogues

Forked from [ACDTools](https://github.com/Thomas-Moore-Creative/ACDtools) by @Thomas-Moore-Creative

___
## This package is a collection of utilities for working with the ACCESS-NRI intake catalogues. 

It provides tools for:
- Loading ensembles
- Getting information about chunking
amongst other things, and is designed to be a place where ACCESS-NRI Intake Catalog users can share their utilities for working with catalogues.


![PyPI version](https://img.shields.io/pypi/v/access-intake-utils.svg)
![Build Status](https://img.shields.io/travis/access-nri/access_intake_utils.svg)
![Documentation Status](https://readthedocs.org/projects/access-intake-utils/badge/?version=latest)

- Free software: Apache 2.0 Software Licence
- Documentation: https://access-intake-utils.readthedocs.io.
